@@ -170,39 +170,13 @@ internal_krb5_gss_initialize(void *dl)
 	void **fptr;
 	int i;
 	static gss_mechanism krb5_mech_ptr = (gss_mechanism)0xdeadbeef;
-	char *prefix;
-	char *test_function = "gss_acquire_cred";
+	char *prefix = "";
 
 	if (krb5_mech_ptr != (gss_mechanism) 0xdeadbeef)
 		return (krb5_mech_ptr);
 
-	/*
-	 * We'll assume we can use either an MIT or Hiemdal gss library.
-	 * Currently (Nov 7, 2005), Hiemdal exports functions only with
-	 * the name gss_*.  MIT exports functions with names krb5_gss_*.
-	 * In the future, Heimdal may export functions with the krb5_
-	 * prefix as well.
-	 * If we find the symbol krb5_gss_acquire_cred, we assume that
-	 * all functions will have the "krb5_" prefix.  If we don't
-	 * find either krb5_gss_acquire_cred or gss_acquire_cred, then
-	 * this mechanism library isn't going to be very useful.
-	 */
-	p = locate_symbol(dl, test_function, "krb5_");
-	if (p != (void *)-1) {
-		prefix = "krb5_";
-	} else {
-		p = locate_symbol(dl, test_function, "");
-		if (p != (void *)-1) {
-			prefix = "";
-		} else {
-			krb5_mech_ptr = NULL;
-			goto out;
-		}
-	}
-
 	fptr = (void *) &krb5_mechanism.gss_acquire_cred;
 
-
 	for (i = 0, fname = glue_func_names[i];
 	     fname;
 	     i++, fname = glue_func_names[i]) {
